add vtable relocs for Alpha

Philip Blundell pb@futuretv.com
Wed Jan 3 02:44:00 GMT 2001


Any objections to this patch?

p.

2001-01-03  Philip Blundell  <pb@futuretv.com>

	* alpha.h: Add GNU_VTINHERIT and GNU_VTENTRY relocs.

Index: alpha.h
===================================================================
RCS file: /cvs/src/src/include/elf/alpha.h,v
retrieving revision 1.3
diff -u -r1.3 alpha.h
--- alpha.h	2000/06/07 04:08:12	1.3
+++ alpha.h	2001/01/03 10:43:43
@@ -1,5 +1,5 @@
 /* ALPHA ELF support for BFD.
-   Copyright (C) 1996, 98, 2000 Free Software Foundation, Inc.
+   Copyright (C) 1996, 98, 2000, 2001 Free Software Foundation, Inc.
 
    By Eric Youngdale, <eric@aib.com>.  No processor supplement available
    for this platform.
@@ -46,7 +46,7 @@
 /* Section contains register usage information.  */
 #define SHT_ALPHA_REGINFO	0x70000002
 
 /* A section of type SHT_MIPS_REGINFO contains the following
    structure.  */
 typedef struct
 {
@@ -102,6 +102,9 @@
   RELOC_NUMBER (R_ALPHA_JMP_SLOT, 26)	/* Create PLT entry */
   RELOC_NUMBER (R_ALPHA_RELATIVE, 27)	/* Adjust by program base */
 
+/* These are GNU extensions to enable C++ vtable garbage collection.  */
+  RELOC_NUMBER (R_ALPHA_GNU_VTINHERIT, 250)
+  RELOC_NUMBER (R_ALPHA_GNU_VTENTRY, 251)
 END_RELOC_NUMBERS (R_ALPHA_max)
 
 #endif /* _ELF_ALPHA_H */
@@ -46,7 +46,7 @@
 #define SHT_ALPHA_REGINFO	0x70000002
 
-/* A section of type SHT_MIPS_REGINFO contains the following
+/* A section of type SHT_ALPHA_REGINFO contains the following
    structure.  */
 typedef struct




More information about the Binutils mailing list